@@ -137,7 +137,7 @@ def copy_venue_skel(venue_path):
         raise
     return True
 
-def create_venue_uwsgi_file(VENUE_ROOT, VENUE_NAME):
+def create_venue_uwsgi_file(VENUE_BASE, VENUE_ROOT, VENUE_NAME):
     """create the uwsgi ini file for a (usually) new Venue.
     Reads backstage/config/uwsgi.venue.ini.src
     """
@@ -146,14 +146,14 @@ def create_venue_uwsgi_file(VENUE_ROOT, VENUE_NAME):
         srcdata = f.read()
     outfile = os.path.join(VENUE_ROOT, 'backstage-%s-uwsgi.ini' % (VENUE_NAME))
     o = open(outfile, 'w')
-    o.write(srcdata.format(VENUE_ROOT=VENUE_ROOT, VENUE_NAME=VENUE_NAME))
+    o.write(srcdata.format(VENUE_BASE=VENUE_BASE, VENUE_ROOT=VENUE_ROOT, VENUE_NAME=VENUE_NAME))
     o.close()
     return
 
 
-def new_venue(venue_name, venue_path, source_ini_file = None):
+def new_venue(venue_name, venue_base, source_ini_file = None):
         """create a new backstage venue with the given name and located at the specified path"""
-        venue_path = os.path.abspath(os.path.join(venue_path, venue_name))
+        venue_path = os.path.abspath(os.path.join(venue_base, venue_name))
         try:
             os.makedirs(venue_path)
         except:
@@ -175,7 +175,7 @@ def new_venue(venue_name, venue_path, source_ini_file = None):
             raise
 
         try:
-            create_venue_uwsgi_file(venue_path, venue_name)
+            create_venue_uwsgi_file(venue_base, venue_path, venue_name)
         except:
             s = 'Error in create_venue_wsgi_file'
             print s
